package EFS::Config::Client;

use strict;
use warnings;
use English;

use Params::Validate qw( :all );
use Config::Tiny;
use Moose;

has q{_data} => (
    is  => q{rw},
    isa => q{Config::Tiny},
);

{

    sub BUILD {

        my ($self, $args_ref) = @_;

        my @args = %{ $args_ref };

        my (%args) = validate( @args, {
            file => { type     => SCALAR,
                      default  => q{/etc/efs/client.conf},
                      optional => 1 },
        });

        if ( -f $args{file} ) {
            $self->_data( Config::Tiny->read( $args{file} ) );
        }

        if ( not $self->_data->{client} ) {
            die(
                qq{Invalid config file: $args{file}\n},
                qq{Missing required section 'client'\n},
            );
        }

        foreach my $required ( qw( cell hosttype ) ) {
            if ( not $self->_data->{client}->{$required} ) {
                die(
                    qq{Invalid config file: $args{file}\n},
                    qq{Missing required database parameter '$required'\n},
                );
            }
        }

        return;
    }

    sub get_value {
        my ($self,$section,$key)= @_;
        return $self->_data->{$section}->{$key};
    }

}

no Moose;
__PACKAGE__->meta->make_immutable;
1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
