package EFS::DBI::Result::DependencyRelease;

use strict;
use warnings;
use English;

use base q{EFS::DBI::Dependency};
use base q{EFS::DBI::Result};

__PACKAGE__->load_components( qw/+EFS::DBI::Prefix Core/ );

__PACKAGE__->table( q{dependency_release} );

__PACKAGE__->add_columns( qw( dependent_release release type ) );
__PACKAGE__->add_columns(
    id => { __PACKAGE__->get_id_column_attrs },
);
__PACKAGE__->set_primary_key( q{id} );
__PACKAGE__->sequence( q{dependency_release_seq} );

__PACKAGE__->belongs_to( dependent_release => q{EFS::DBI::Result::Release} );
__PACKAGE__->belongs_to( release           => q{EFS::DBI::Result::Release} );

sub display_headers {
    return qw( Dependent Release Type );
}

sub display_columns {
    return qw( dependent_object_id release_object_id type );
}

sub dependent_release_object_id {
    return shift->dependent_release->object_id;
}

sub release_object_id {
    return shift->release->object_id;
}

sub dependent_metaproj {
    return shift->dependent_release->metaproj;
}

sub dependent_project {
    return shift->dependent_release->project;
}

sub metaproj {
    return shift->release->metaproj;
}

sub project {
    return shift->release->project;
}

sub target {
    return shift->release;
}

1;

# Local Variables:
#   mode: cperl
#   cperl-indent-level: 4
#   fill-column: 78
# End:
# vim: expandtab shiftwidth=4:
