#!/usr/bin/env perl
use strict;
use warnings;
use English;

use IO::File;
use Test::More;
use File::Basename qw( basename );

use blib;
use EFS;

use lib q{test/lib};
use EFS::Test::Config;

my $config = EFS::Test::Config->new;

my $sshcmd        = $config->get_value( q{Global}, q{sshcmd} );
my $ldc_name      = $config->get_value( q{LocalDevCell}, q{name} );
my $rdc_name      = $config->get_value( q{RemoteDevCell}, q{name} );
my $rdc_efsserver = $config->get_value( q{RemoteDevCell}, q{efsserver} );

if ( not -d q{/etc/efs} ) {
    mkdir( q{/etc/efs}, 0755 ) or die qq{Unable to mkdir /etc/efs: $ERRNO\n};
}

my $conf = IO::File->new(q{>/etc/efs/client.conf}) ||
    die qq{Unable to write to /etc/efs/client.conf: $ERRNO\n};
ok( $conf, q{open /etc/efs/client.conf} );

$conf->print(<<"EOF");
#
# This is auto-generated by test/00_setup/21_clientconf.t
# Don't mess with it
#
[client]
    cell        = $ldc_name
    hosttype    = test
EOF

ok( $conf->close, q{wrote /etc/efs/client.conf} );

my $conf_remote = IO::File->new(q{>/etc/efs/client_remote.conf}) ||
    die qq{Unable to write to /etc/efs/client_remote.conf: $ERRNO\n};
ok( $conf_remote, q{open /etc/efs/client_remote.conf} );

$conf_remote->print(<<"EOF");
#
# This is auto-generated by test/00_setup/21_clientconf.t
# Don't mess with it
#
[client]
    cell        = $rdc_name
    hosttype    = test
EOF

ok( $conf_remote->close, q{wrote /etc/efs/client_remote.conf} );

system (  qq{rsync --rsh='$sshcmd' -avz }
        . qq{/etc/efs/client_remote.conf $rdc_efsserver:/etc/efs/client.conf} );
ok( $CHILD_ERROR == 0, qq{rsync /etc/efs/client.conf -> $rdc_efsserver} );

done_testing();
exit 0;

sub makelink {

    my ( $to, $from ) = @_;

    if ( -l $from ) {
        my $readlink = readlink ($from) || die qq{Unable to readlink $from: $ERRNO\n};
        if ( $readlink eq $to ) {
            return 1;
        }
        unlink ($to) || die qq{Unable to unlink $to: $ERRNO\n};
    }

    symlink ( $to, $from ) || die qq{Unable to symlink $from -> $to: $ERRNO\n};

    return 1;

}

1;
