#!/usr/bin/env perl

use strict;
use warnings;
use English;

use Test::More tests => 18;

use lib q{test/lib};
use EFS::Test;

my $test = EFS::Test->new( as_user => q{primary_user} );

my $username  = $test->get_primary_username;
my $groupname = $test->get_primary_groupname;

my @setup = (
    q{efs display metaproj testmeta},
    q{efs display project testmeta testproj},
);

foreach my $setup (@setup) {
    $test->efs_test_command(
        name    => qq{(setup) $setup},
        command => $setup,
        bail    => 1,
    );
}

$test->efs_test_command(
    command => q{efs display release testmeta testproj testrel},
    not     => 1,
    bail    => 1,
);

my $dev_path = q{/efs/dev/testmeta/testproj/testrel};

$test->efs_test_command(
    command => q{efs create release testmeta testproj testrel},
    expect  => [
        qq{Created directory $dev_path},
        qq{Created directory $dev_path/install},
        qq{Created directory $dev_path/build},
        qq{Changed ownership of $dev_path/build to $username/$groupname},
        qq{Created directory $dev_path/src},
        qq{Changed ownership of $dev_path/src to $username/$groupname},
        qq{Creating dist2dev symlink for testmeta/testproj/testrel},
        qr{Created directory \S+:/efs/dist/testmeta}ms,
        qr{Created directory \S+:/efs/dist/testmeta/testproj}ms,
        qr{Created symlink \S+:/efs/dist/testmeta/testproj/testrel -> $dev_path/install}ms,
        q{Created release testmeta/testproj/testrel},
    ],
);

$test->efs_test_directory( directory => $dev_path );

$test->efs_test_directory( directory => qq{$dev_path/install} );

$test->efs_test_directory(
    directory => qq{$dev_path/src},
    user      => $username,
    group     => $groupname,
);

$test->efs_test_directory(
    directory => qq{$dev_path/build},
    user      => $username,
    group     => $groupname,
);

$test->efs_test_command(
    command => q{touch /efs/dev/testmeta/testproj/testrel/src/notempty},
);

$test->efs_test_command(
    command => q{efs create release testmeta testproj clonesrc --clonesrc testrel},
);

$test->efs_test_file(
    file  => q{/efs/dev/testmeta/testproj/clonesrc/src/notempty},
    user  => $username,
    group => $groupname,
);

$test->efs_test_command(
    command => q{efs setstage release testmeta testproj testrel rejected},
    expect  => q{Changed the stage of testmeta/testproj/testrel from dev to rejected},
);

my @expect = (
    qr{Removed dist2dev symlink \S+:/efs/dist/testmeta/testproj/testrel}ms,
    q{Renamed /efs/dev/testmeta/testproj/testrel to } .
        q{/efs/dev/testmeta/testproj/.destroyed/testrel},
    qq{Destroyed $dev_path},
    q{Successfully destroyed testmeta/testproj/testrel globally},
);

if ( not -d q{/efs/dev/testmeta/testproj/.destroyed} ) {
    unshift @expect,
        q{Created directory /efs/dev/testmeta/testproj/.destroyed};
}

$test->efs_test_command(
    command => q{efs destroy release testmeta testproj testrel},
    expect  => \@expect,
);

$test->efs_test_directory(
    directory => $dev_path,
    not       => 1,
);

$test->efs_test_command(
    command => q{efs purge release testmeta testproj testrel --now},
    expect => [
        q{Removed directory /efs/dev/testmeta/testproj/.destroyed/testrel},
        q{Purged 'testmeta/testproj/testrel' from /efs/dev},
        q{Successfully purged 'testmeta/testproj/testrel' from all cells},
    ],
);

$test->efs_test_command(
    command => q{efs setstage release testmeta testproj clonesrc rejected},
);

$test->efs_test_command(
    command => q{efs destroy release testmeta testproj clonesrc},
);

$test->efs_test_command(
    command => q{efs purge release testmeta testproj clonesrc --now},
);

exit 0;
