#!/usr/bin/env perl

use strict;
use warnings;
use English;

use Test::More tests => 10;
use Date::Format qw( time2str );

use lib q{test/lib};
use EFS::Test;

my $test = EFS::Test->new( as_user => q{efsops} );

$test->efs_test_command(
    command => q{efs history any -starttime this_is_not_a_datetime},
    not     => 1,
    expect  => q{Unable to parse starttime value 'this_is_not_a_datetime'},
);

sleep 2;
my $begin = time;

$test->efs_test_command(
    command => q{efs showcerts sslserver},
);

my @history = ();

my $history_id = get_history_id(
    command => q{efs history any -command 'showcerts sslserver' -count 1},
);

my $starttime = time2str( q{%Y-%m-%d %H:%M:%S GMT}, $begin, q{GMT} );

my $starttime_id = get_history_id(
    command => qq{efs history any -starttime '$starttime' -count 1},
);

my $startdate = time2str( q{%Y-%m-%d}, $begin, q{GMT} );

my $startdate_id = get_history_id(
    command => qq{efs history any -startdate '$startdate' -count 1},
);

ok( $history_id == $starttime_id, q{Query via -starttime works} );
ok( $history_id == $startdate_id, q{Query via -startdate works} );

sub get_history_id {

    my (%args) = @_;

    my @output = ();

    $test->efs_test_command(
        command => $args{command},
        output => \@output,
    );

    my $command_id;

    foreach my $output ( @output ) {
        ## no critic: ProhibitCaptureWithoutTest
        next unless $output =~ m{^\s+(\d+)}msx;
        $command_id = $1;
        last;
    }

    ok( $command_id, q{Found history ID via the CLI} );

    return $command_id;

}

exit 0;
