#!/usr/bin/env perl

use strict;
use warnings;
use English;

use Test::More qw( no_plan );

use lib q{test/lib};
use EFS::Test;

my $test = EFS::Test->new( as_user => q{efsops} );

my $region   = q{testregion};
my $campus   = q{testcampus};
my $location = q{testlocation};

my @setup = (
    qq{efs define region $region 'test region'},
    qq{efs define campus $region $campus 'test campus'},
    qq{efs define location $region $campus $location 'test location'},
);

foreach my $command (@setup) {
    $test->efs_test_command(
        name    => qq{(setup) $command},
        command => $command,
    );
}

my $cabinet = q{floor/room/bay/testcabinet};

$test->efs_test_command(
    command => qq{efs define cabinet $location $cabinet},
    expect  => qr{Defined \s+ cabinet \s+ $location/$cabinet, \s+ id \s+ = \s+ \d+}msx,
);

$test->efs_test_command(
    command => qq{efs define cabinet $location $cabinet},
    expect  => qq{Cabinet $location/$cabinet already exists.},
);

my @display = (
    qr{Location \s+ Cabinet}msx,
    qr{^=+}msx,
    qr{$location \s+ $cabinet}msx,
);

$test->efs_test_command(
    command => qq{efs display cabinet $location $cabinet},
    expect  => \@display,
);

$test->efs_test_command(
    command => qq{efs display cabinet $location},
    expect  => \@display,
);

$test->efs_test_command(
    command => qq{efs setattr cabinet $location $cabinet foo bar}, );

$test->efs_test_command(
    command => qq{efs display cabinet $location $cabinet},
    expect  => [
        @display,
        qr{Location \s+ Cabinet \s+ Attribute \s+ Value}msx,
        qr{=+}msx,
        qr{$location \s+ $cabinet \s+ foo \s+ bar}msx,
    ],
);

$test->efs_test_command(
    command => qq{efs undef location $region $campus $location},
    not     => 1,
    expect  => [
        qq{Unable to undef location $region/$campus/$location, because it has},
        q{the following cabinets:},
        qq{$cabinet},
    ],
);

$test->efs_test_command(
    command => qq{efs undef cabinet $location $cabinet},
    expect  => qq{Undefined cabinet $location/$cabinet},
);

$test->efs_test_command(
    command => qq{efs history cabinet $location $cabinet -count 4},
    expect  => [
        qr{History \s+ ID \s+ StartTime \s+ Duration \s+ Status \s+ Authuser \s+ Request}msx,
        qr{-+}msx,
        qr{define \s+ cabinet \s+ $location \s+ $cabinet}msx,
        qr{define \s+ cabinet \s+ $location \s+ $cabinet}msx,
        qr{setattr \s+ cabinet \s+ $location \s+ $cabinet}msx,
        qr{undef \s+ cabinet \s+ $location \s+ $cabinet}msx,
    ],
);

my @teardown = (
    qq{efs undef location $region $campus $location},
    qq{efs undef campus $region $campus},
    qq{efs undef region $region},
);

foreach my $command (@teardown) {
    $test->efs_test_command(
        name    => qq{(teardown) $command},
        command => $command,
    );
}

