#!/usr/bin/env perl

use strict;
use warnings;
use English;

use IO::File;
use Try::Tiny;

use lib q{test/lib};
use EFS::Test::Config;
use Test::More qw( no_plan );

use DBI;

my $config = EFS::Test::Config->new;

my $connect  = $config->get_value( q{Database}, q{connect} );
my $dbouser  = $config->get_value( q{Database}, q{dbouser} );
my $dbopass  = $config->get_value( q{Database}, q{dbopasswd} );
my $rwuser   = $config->get_value( q{Database}, q{rwuser} );
my $dbvendor = $config->get_value( q{Database}, q{dbvendor} );

my $rdc_efsserver = $config->get_value( q{RemoteDevCell}, q{efsserver} );
my $sshcmd        = $config->get_value( q{Global}, q{sshcmd} );

my $dbh = DBI->connect(
    $connect,
    $dbouser,
    $dbopass,
    {
        AutoCommit        => 1,
        RaiseError        => 1,
    }
);

ok( $dbh, q{DBI->connect} );

my $count = 0;

foreach my $sqlfile ( qq{sql/$dbvendor/destroy.sql} ) {

    my $io = IO::File->new( $sqlfile ) ||
        die qq{Unable to open $sqlfile: $ERRNO\n};

    my @data = ();

    while ( defined($_ = $io->getline) ) {
        chomp;
        next if /^--/msx;
        next if /^\s*$/msx;
        push @data, $_;
    }

    my $data = join( q{ }, @data );

    my @sql = split ( /;+/msx, $data );

    foreach my $sql ( @sql ) {
        next unless $sql; # skip empty statements
        my $show = substr( $sql, 0, 60 );
        $show .= q{ ... } if length($sql) > 60;
        try { $dbh->do( $sql ) }
        catch {
            warn qq{SQL Failed: $DBI::errstr\n$EVAL_ERROR\n};
        };
        ok( !$EVAL_ERROR, qq{SQL statement: $show} );
    }

}

unlink( q{/etc/efs/server.conf} ) ||
    die qq{Unable to unlink /etc/efs/server.conf: $ERRNO\n};
ok( 1, q{unlink /etc/efs/server.conf} );

system qq{$sshcmd $rdc_efsserver /bin/rm /etc/efs/server.conf};
ok( $CHILD_ERROR == 0, qq{unlink $rdc_efsserver:/etc/efs/server.conf} );

if ( -f qq{/var/efs/etc/passwd/$rwuser} ) {
    unlink( qq{/var/efs/etc/passwd/$rwuser} ) ||
        die qq{Unable to unlink /var/efs/etc/passwd/$rwuser: $ERRNO\n};
}
ok( 1, qq{unlink /var/efs/etc/passwd/$rwuser} );

1;
